local events = {}

-- PLACE EVENT HANDLERS HERE, NAMED AS THE EVENT THEY SHOULD HANDLE

--- Called for each combat log event.
function events:COMBAT_LOG_EVENT_UNFILTERED(timestamp, event, hideCaster, sourceGUID, sourceName, sourceFlags, sourceFlags2, destGUID, destName, destFlags, destFlags2)
  if (event == "PARTY_KILL") then
    Tally.record_mob_kill(Tally.ParseGUID(destGUID))
  end
end

--- Called for each mouseover unit event
function events:UPDATE_MOUSEOVER_UNIT(...)
  Tally.store_data("mouseover")
end

function events:PLAYER_TARGET_CHANGED(arg1)
  if (UnitGUID("target")) then
    Tally.store_data("target")
  end
end

--- Called when the loot window opens
function events:LOOT_OPENED(...)
  Tally.parseLootEvent()
end

function Tally.handle_running_message(self, event, msg, author, ...)
  if msg:find("attempts to run away in fear!") then
	Tally.record_mob_runs(author)
  end
end

-- END OF EVENT HANDLER AREA

--- Register the events associated with events above.
function Tally.RegisterEvents(self)
  for func, _ in pairs(events) do
    self:RegisterEvent(func)
  end
  
  ChatFrame_AddMessageEventFilter("CHAT_MSG_MONSTER_EMOTE", Tally.handle_running_message)
end

--- Set up ACE3 localisation
function Tally.InitialiseLocalisation()
  Tally.L = LibStub("AceLocale-3.0"):GetLocale("Tally")
end

--- The addon has loaded.  Deal with anything we need to cover at load time.
function TallyLoadHandler(self)
  Tally.InitialiseLocalisation()
  print (Tally.L["WELCOME"])
  Tally.RegisterEvents(self)
  
  -- initialise the tooltip we are drawing to.
 -- Tally.InitializeTooltip()
end


--- An event has occurred and we registered an interest in it.  Call our event handler for that event.
function TallyEventHandler(self, event, ...)
  events[event](self, ...)
end

function Tally.store_data(unitId)
  local NPCid, mobType = Tally.ParseGUID(UnitGUID(unitId))
  -- Only store if it is a NPC
  if (mobType == "NPC") then
    local name = UnitName(unitId)
    local location = GetRealZoneText()
    local level = UnitLevel(unitId)
    Tally.record_mob(NPCid, name, location, level)
  end
end -- function Tally.store_data